NetworkX 2.8.2
==============

Release date: 21 May 2022

Supports Python 3.8, 3.9, and 3.10.

NetworkX is a Python package for the creation, manipulation, and study of the
structure, dynamics, and functions of complex networks.

For more information, please visit our `website <https://networkx.org/>`_
and our :ref:`gallery of examples <examples_gallery>`.
Please send comments and questions to the `networkx-discuss mailing list
<http://groups.google.com/group/networkx-discuss>`_.

Highlights
----------

Minor documentation and bug fixes.

Merged PRs
----------

- Fix doc deploy
- Bump release version
- MAINT: Update dfs_test with more comprehensive tests (#5654)
- Bump release version
- Fix __setstate__ for OutEdgeView subclasses, read _adjdict from state (#5657)
- Add examples & improve documentation of voterank (#5500)

Contributors
------------

- Jarrod Millman
- Mridul Seth
- Dilara Tekinoglu
